==> topia-service-migration-2.3.0-beta-1-sources.jar: org/nuiton/topia/migration/MigrationServiceException.java <==
/* *##% ToPIA - Migration service
 * Copyright (C) 2004 - 2009 CodeLutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>. ##%*/

package org.nuiton.topia.migration;

/**
 * TopiaMigrationServiceException.java
 *
 * @author Chatellier Eric
 * @author Chevallereau Benjamin
 * @author Eon Sébastien
 * @author Trève Vincent
 * @version $Revision: 1459 $
 *
 * Last update : $Date: 2009-05-16 09:56:47 +0200 (Sat, 16 May 2009) $
 */
public class MigrationServiceException extends Exception {

	/**
	 * Version
	 */
	private static final long serialVersionUID = -8900901171551405745L;
	
	/**
	 * Constructeur par defaut
	 */
	public MigrationServiceException() {
		super();
	}
	
	/**
	 * Constructeur avec message
	 * @param message Le message d'erreur
	 */
	public MigrationServiceException(String message) {
		super(message);
	}
	
	/**
	 * Constructeur avec message et exception
	 * @param message Le message d'erreur
	 * @param exception l'exception
	 */
	public MigrationServiceException(String message, Throwable exception) {
		super(message, exception);
	}

	/**
	 * Constructeur avec exception
	 * @param exception l'exception
	 */
	public MigrationServiceException(Throwable exception) {
		super(exception);
	}
}

==> topia-service-migration-3.0-beta-1-sources.jar: org/nuiton/topia/migration/MigrationServiceException.java <==
package org.nuiton.topia.migration;

/*
 * #%L
 * ToPIA :: Service Migration
 * $Id: MigrationServiceException.java 2984 2014-01-18 20:43:10Z athimel $
 * $HeadURL: https://svn.nuiton.org/topia/tags/topia-3.0-beta-1/topia-service-migration/src/main/java/org/nuiton/topia/migration/MigrationServiceException.java $
 * %%
 * Copyright (C) 2004 - 2014 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

/**
 * TopiaMigrationServiceException.java
 *
 * @author Chatellier Eric
 * @author Chevallereau Benjamin
 * @author Eon Sébastien
 * @author Trève Vincent
 */
public class MigrationServiceException extends Exception {

	/**
	 * Version
	 */
	private static final long serialVersionUID = -8900901171551405745L;
	
	/**
	 * Constructeur par defaut
	 */
	public MigrationServiceException() {
	}
	
	/**
	 * Constructeur avec message
	 * @param message Le message d'erreur
	 */
	public MigrationServiceException(String message) {
		super(message);
	}
	
	/**
	 * Constructeur avec message et exception
	 * @param message Le message d'erreur
	 * @param exception l'exception
	 */
	public MigrationServiceException(String message, Throwable exception) {
		super(message, exception);
	}

	/**
	 * Constructeur avec exception
	 * @param exception l'exception
	 */
	public MigrationServiceException(Throwable exception) {
		super(exception);
	}
}
